@@ -51,6 +51,7 @@
 #include "burn-track.h"
 #include "burn-medium.h"
 #include "burn-session.h"
+#include "burn-plugin-manager.h"
 #include "brasero-ncb.h"
 #include "brasero-drive-selection.h"
 #include "brasero-drive-properties.h"
@@ -90,92 +91,16 @@ static BraseroDriveSelectionClass* parent_class = NULL;
 
 G_DEFINE_TYPE (BraseroDestSelection, brasero_dest_selection, BRASERO_TYPE_DRIVE_SELECTION);
 
-#define BRASERO_DRIVE_PROPERTIES_KEY		"/apps/brasero/drives"
-
 enum {
 	VALID_MEDIA_SIGNAL,
 	LAST_SIGNAL
 };
 static guint brasero_dest_selection_signals [LAST_SIGNAL] = { 0 };
 
-static gchar *
-brasero_dest_selection_get_config_key (BraseroTrackDataType input,
-				       NautilusBurnDrive *drive,
-				       const gchar *property)
-{
-	BraseroMedia media;
-	gchar *display_name;
-	gchar *disc_type;
-	gchar *key = NULL;
-
-	media = NCB_MEDIA_GET_STATUS (drive);
-
-	/* make sure display_name doesn't contain any forbidden characters */
-	display_name = nautilus_burn_drive_get_name_for_display (drive);
-	g_strdelimit (display_name, " +()", '_');
-
-	disc_type = g_strdup (NCB_MEDIA_GET_TYPE_STRING (drive));
-	if (!disc_type) {
-		g_free (display_name);
-		return NULL;
-	}
-
-	g_strdelimit (disc_type, " +()", '_');
-
-	switch (input) {
-	case BRASERO_TRACK_TYPE_NONE:
-		key = g_strdup_printf ("%s/%s/none_%s/%s",
-				       BRASERO_DRIVE_PROPERTIES_KEY,
-				       display_name,
-				       disc_type,
-				       property);
-		break;
-	case BRASERO_TRACK_TYPE_DISC:
-		key = g_strdup_printf ("%s/%s/disc_%s/%s",
-				       BRASERO_DRIVE_PROPERTIES_KEY,
-				       display_name,
-				       disc_type,
-				       property);
-		break;
-
-	case BRASERO_TRACK_TYPE_DATA:
-		key = g_strdup_printf ("%s/%s/data_%s/%s",
-				       BRASERO_DRIVE_PROPERTIES_KEY,
-				       display_name,
-				       disc_type,
-				       property);
-		break;
-
-	case BRASERO_TRACK_TYPE_IMAGE:
-		key = g_strdup_printf ("%s/%s/image_%s/%s",
-				       BRASERO_DRIVE_PROPERTIES_KEY,
-				       display_name,
-				       disc_type,
-				       property);
-		break;
-
-	case BRASERO_TRACK_TYPE_AUDIO:
-		key = g_strdup_printf ("%s/%s/audio_%s/%s",
-				       BRASERO_DRIVE_PROPERTIES_KEY,
-				       display_name,
-				       disc_type,
-				       property);
-		break;
-	default:
-		break;
-	}
-
-	g_free (display_name);
-	g_free (disc_type);
-	return key;
-}
-
 static void
 brasero_dest_selection_save_drive_properties (BraseroDestSelection *self)
 {
 	BraseroDestSelectionPrivate *priv;
-	NautilusBurnDrive *drive;
-	BraseroTrackType input;
 	BraseroBurnFlag flags;
 	GConfClient *client;
 	const gchar *path;
@@ -185,15 +110,6 @@ brasero_dest_selection_save_drive_properties (BraseroDestSelection *self)
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (self);
 
-	drive = brasero_burn_session_get_burner (priv->session);
-	if (!drive)
-		return;
-
-	if (NCB_MEDIA_GET_STATUS (drive) == BRASERO_MEDIUM_NONE)
-		return;
-
-	brasero_burn_session_get_input_type (priv->session, &input);
-
 	client = gconf_client_get_default ();
 
 	rate = brasero_burn_session_get_rate (priv->session);
@@ -202,11 +118,11 @@ brasero_dest_selection_save_drive_properties (BraseroDestSelection *self)
 	else
 		speed = BRASERO_RATE_TO_SPEED_CD (rate);
 
-	key = brasero_dest_selection_get_config_key (input.type, drive, "speed");
+	key = brasero_burn_session_get_config_key (priv->session, "speed");
 	gconf_client_set_int (client, key, speed, NULL);
 	g_free (key);
 
-	key = brasero_dest_selection_get_config_key (input.type, drive, "flags");
+	key = brasero_burn_session_get_config_key (priv->session, "flags");
 	flags = gconf_client_get_int (client, key, NULL);
 	flags &= ~BRASERO_DRIVE_PROPERTIES_FLAGS;
 	flags |= (brasero_burn_session_get_flags (priv->session) & BRASERO_DRIVE_PROPERTIES_FLAGS);
@@ -782,6 +698,101 @@ brasero_dest_selection_properties_button_cb (GtkWidget *button,
 		brasero_dest_selection_drive_properties (self);
 }
 
+static void
+brasero_dest_selection_add_drive_properties_flags (BraseroDestSelection *self,
+						   BraseroBurnFlag flags,
+						   BraseroBurnFlag *supported_retval,
+						   BraseroBurnFlag *compulsory_retval)
+{
+	BraseroDestSelectionPrivate *priv;
+	BraseroBurnFlag supported = BRASERO_BURN_FLAG_NONE;
+	BraseroBurnFlag compulsory = BRASERO_BURN_FLAG_NONE;
+
+	priv = BRASERO_DEST_SELECTION_PRIVATE (self);
+
+	/* wipe out previous flags */
+	brasero_burn_session_remove_flag (priv->session,
+					  BRASERO_DRIVE_PROPERTIES_FLAGS|
+					  BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE|
+					  BRASERO_BURN_FLAG_FAST_BLANK|
+					  BRASERO_BURN_FLAG_DAO);
+
+	/* check each flag before re-adding it */
+	brasero_burn_caps_get_flags (priv->caps,
+				     priv->session,
+				     &supported,
+				     &compulsory);
+
+	if ((flags & BRASERO_BURN_FLAG_EJECT)
+	&&  (supported & BRASERO_BURN_FLAG_EJECT)) {
+		brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_EJECT);
+		brasero_burn_caps_get_flags (priv->caps,
+					     priv->session,
+					     &supported,
+					     &compulsory);
+	}
+
+	if ((flags & BRASERO_BURN_FLAG_BURNPROOF)
+	&&  (supported & BRASERO_BURN_FLAG_BURNPROOF)) {
+		brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_BURNPROOF);
+		brasero_burn_caps_get_flags (priv->caps,
+					     priv->session,
+					     &supported,
+					     &compulsory);
+	}
+
+	if ((flags & BRASERO_BURN_FLAG_NO_TMP_FILES)
+	&&  (supported & BRASERO_BURN_FLAG_NO_TMP_FILES)) {
+		brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_NO_TMP_FILES);
+		brasero_burn_caps_get_flags (priv->caps,
+					     priv->session,
+					     &supported,
+					     &compulsory);
+	}
+
+	if ((flags & BRASERO_BURN_FLAG_DUMMY)
+	&&  (supported & BRASERO_BURN_FLAG_DUMMY)) {
+		brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_DUMMY);
+		brasero_burn_caps_get_flags (priv->caps,
+					     priv->session,
+					     &supported,
+					     &compulsory);
+	}
+
+	/* check additional flags */
+	if (supported & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE) {
+		/* clean up the disc and have more space when possible */
+		brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE);
+		brasero_burn_caps_get_flags (priv->caps,
+					     priv->session,
+					     &supported,
+					     &compulsory);
+
+		if (supported & BRASERO_BURN_FLAG_FAST_BLANK) {
+			brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_FAST_BLANK);
+			brasero_burn_caps_get_flags (priv->caps,
+						     priv->session,
+						     &supported,
+						     &compulsory);
+		}
+	}
+
+	/* use DAO whenever it's possible */
+	if (supported & BRASERO_BURN_FLAG_DAO) {
+		brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_DAO);
+		brasero_burn_caps_get_flags (priv->caps,
+					     priv->session,
+					     &supported,
+					     &compulsory);
+	}
+	brasero_burn_session_add_flag (priv->session, compulsory);
+
+	if (supported_retval)
+		*supported_retval = supported;
+	if (compulsory_retval)
+		*compulsory_retval = compulsory;
+}
+
 static void
 brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 {
@@ -829,7 +840,7 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 	/* update/set the rate */
 	client = gconf_client_get_default ();
 
-	key = brasero_dest_selection_get_config_key (source.type, drive, "speed");
+	key = brasero_burn_session_get_config_key (priv->session, "speed");
 	value = gconf_client_get_without_default (client, key, NULL);
 	g_free (key);
 
@@ -846,8 +857,11 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 
 	brasero_burn_session_set_rate (priv->session, rate);
 
-	/* do the same with the flags */
-	key = brasero_dest_selection_get_config_key (source.type, drive, "flags");
+	/* do the same with the flags.
+	 * NOTE: every time we add a flag we have to re-ask for supported flags.
+	 * Indeed two flags could be mutually exclusive and then adding both at
+	 * the same would make the session unusable (MULTI and BLANK_BEFORE_WRITE) */
+	key = brasero_burn_session_get_config_key (priv->session, "flags");
 	value = gconf_client_get_without_default (client, key, NULL);
 	g_free (key);
 
@@ -856,99 +870,83 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 		BraseroBurnFlag supported = BRASERO_BURN_FLAG_NONE;
 		BraseroBurnFlag compulsory = BRASERO_BURN_FLAG_NONE;
 
-		/* here we don't check is the medium is supported ... */
-		result = brasero_burn_caps_get_flags (priv->caps,
-						      priv->session,
-						      &supported,
-						      &compulsory);
+		flags = BRASERO_BURN_FLAG_EJECT|
+			BRASERO_BURN_FLAG_BURNPROOF;
 
-		/* these are sane defaults */
-		brasero_burn_session_add_flag (priv->session,
-					       BRASERO_BURN_FLAG_EJECT|
-					       BRASERO_BURN_FLAG_BURNPROOF);
+		if (source.type == BRASERO_TRACK_TYPE_DATA
+		||  source.type == BRASERO_TRACK_TYPE_DISC
+		||  source.type == BRASERO_TRACK_TYPE_IMAGE)
+			flags |= BRASERO_BURN_FLAG_NO_TMP_FILES;
 
-		brasero_burn_session_remove_flag (priv->session, BRASERO_BURN_FLAG_DUMMY);
-
-		if (supported & BRASERO_BURN_FLAG_NO_TMP_FILES) {
-			if (source.type == BRASERO_TRACK_TYPE_DATA
-			||  source.type == BRASERO_TRACK_TYPE_DISC
-			||  source.type == BRASERO_TRACK_TYPE_IMAGE)
-				brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_NO_TMP_FILES);
-			else
-				brasero_burn_session_remove_flag (priv->session, BRASERO_BURN_FLAG_NO_TMP_FILES);
-		}
-		else
-			brasero_burn_session_remove_flag (priv->session, BRASERO_BURN_FLAG_NO_TMP_FILES);
+		brasero_dest_selection_add_drive_properties_flags (self,
+								   flags,
+								   &supported,
+								   &compulsory);
 
+		/* Now that we updated the session flags see if everything works */
+		result = brasero_burn_caps_is_session_supported (priv->caps, priv->session);
 		g_signal_emit (self,
 			       brasero_dest_selection_signals [VALID_MEDIA_SIGNAL],
 			       0,
 			       (result == BRASERO_BURN_OK));
+
 		gtk_widget_set_sensitive (priv->button, (result == BRASERO_BURN_OK));
+		gtk_widget_set_sensitive (priv->copies_box, (result == BRASERO_BURN_OK));
 	}
 	else if (brasero_dest_selection_check_same_src_dest (self)) {
-		/* special case */
+		/* Special case: better not check if session is supported. */
 
+		/* wipe out previous flags */
+		brasero_burn_session_remove_flag (priv->session,
+						  BRASERO_DRIVE_PROPERTIES_FLAGS|
+						  BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE|
+						  BRASERO_BURN_FLAG_FAST_BLANK|
+						  BRASERO_BURN_FLAG_DAO);
+
+		/* set new ones */
 		flags = gconf_value_get_int (value);
-		brasero_burn_session_remove_flag (priv->session, BRASERO_DRIVE_PROPERTIES_FLAGS);
 		brasero_burn_session_add_flag (priv->session, flags);
+
+		/* NOTE: of course NO_TMP is not possible; DAO and BLANK_BEFORE
+		 * could be yet. The problem here is that we cannot test all
+		 * this since we don't know yet what the disc type is going to 
+		 * be. So we set DAO and BLANK_BEFORE_WRITE just in case.
+		 * Hopefully burn.c will be able to handle that later. */
+		brasero_burn_session_add_flag (priv->session,
+					       BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE|
+					       BRASERO_BURN_FLAG_FAST_BLANK|
+					       BRASERO_BURN_FLAG_DAO);
+
 		g_signal_emit (self,
 			       brasero_dest_selection_signals [VALID_MEDIA_SIGNAL],
 			       0,
 			       TRUE);
 		gtk_widget_set_sensitive (priv->button, TRUE);
+		gtk_widget_set_sensitive (priv->copies_box, TRUE);
 	}
 	else {
 		BraseroBurnResult result;
 		BraseroBurnFlag supported = BRASERO_BURN_FLAG_NONE;
 		BraseroBurnFlag compulsory = BRASERO_BURN_FLAG_NONE;
 
+		/* set the saved flags (make sure they are supported) */
 		flags = gconf_value_get_int (value);
 		gconf_value_free (value);
+		brasero_dest_selection_add_drive_properties_flags (self,
+								   flags,
+								   &supported,
+								   &compulsory);
 
-		result = brasero_burn_caps_get_flags (priv->caps,
-						      priv->session,
-						      &supported,
-						      &compulsory);
+		/* Now that we updated the session flags see if everything works
+		 * if not, unset all flags and retry. */
+		result = brasero_burn_caps_is_session_supported (priv->caps, priv->session);
+		g_signal_emit (self,
+			       brasero_dest_selection_signals [VALID_MEDIA_SIGNAL],
+			       0,
+			       (result == BRASERO_BURN_OK));
 
-		if (result == BRASERO_BURN_OK) {
-			flags &= (supported & BRASERO_DRIVE_PROPERTIES_FLAGS);
-			flags |= (compulsory & BRASERO_DRIVE_PROPERTIES_FLAGS);
-
-			brasero_burn_session_remove_flag (priv->session, BRASERO_DRIVE_PROPERTIES_FLAGS);
-			brasero_burn_session_add_flag (priv->session, flags);
-			g_signal_emit (self,
-				       brasero_dest_selection_signals [VALID_MEDIA_SIGNAL],
-				       0,
-				       TRUE);
-			gtk_widget_set_sensitive (priv->button, TRUE);
-		}
-		else {
-			g_signal_emit (self,
-				       brasero_dest_selection_signals [VALID_MEDIA_SIGNAL],
-				       0,
-				       FALSE);
-			gtk_widget_set_sensitive (priv->button, FALSE);
-		}
-
-		if (supported & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE) {
-			/* clean up the disc and have more space when possible */
-			brasero_burn_session_add_flag (priv->session,
-						       BRASERO_BURN_FLAG_FAST_BLANK|
-						       BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE);
-		}
-		else
-			brasero_burn_session_remove_flag (priv->session,
-							  BRASERO_BURN_FLAG_FAST_BLANK|
-							  BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE);
-
-		/* use DAO whenever it's possible */
-		if (supported & BRASERO_BURN_FLAG_DAO)
-			brasero_burn_session_add_flag (priv->session,
-						       BRASERO_BURN_FLAG_DAO);
-		else
-			brasero_burn_session_remove_flag (priv->session,
-							  BRASERO_BURN_FLAG_DAO);
+		gtk_widget_set_sensitive (priv->copies_box, (result == BRASERO_BURN_OK));
+		gtk_widget_set_sensitive (priv->button, (result == BRASERO_BURN_OK));
 	}
 
 	nautilus_burn_drive_unref (drive);
@@ -1118,6 +1116,7 @@ brasero_dest_selection_check_drive_settings (BraseroDestSelection *self,
 			       TRUE);
 		gtk_widget_set_sensitive (priv->button, TRUE);
 
+		/* These are always set in any case */
 		brasero_burn_session_add_flag (priv->session,
 					       BRASERO_BURN_FLAG_DAO|
 					       BRASERO_BURN_FLAG_FAST_BLANK|
@@ -1125,32 +1124,14 @@ brasero_dest_selection_check_drive_settings (BraseroDestSelection *self,
 		return;
 	}
 
-	/* update the flags for the current drive */
-	result = brasero_burn_caps_get_flags (priv->caps,
-					      priv->session,
-					      &supported,
-					      &compulsory);
-
-	/* send a signal to tell whether we support this disc or not */
-	g_signal_emit (self,
-		       brasero_dest_selection_signals [VALID_MEDIA_SIGNAL],
-		       0,
-		       (result == BRASERO_BURN_OK));
-	gtk_widget_set_sensitive (priv->button, (result == BRASERO_BURN_OK));
-
-	if (priv->button) {
-		if (result != BRASERO_BURN_OK)
-			gtk_widget_set_sensitive (priv->button, FALSE);
-		else
-			gtk_widget_set_sensitive (priv->button, TRUE);
-	}
-
+	/* Try to properly update the flags for the current drive */
 	flags = brasero_burn_session_get_flags (priv->session);
-	flags &= (supported & BRASERO_DRIVE_PROPERTIES_FLAGS);
-	flags |= (compulsory & BRASERO_DRIVE_PROPERTIES_FLAGS);
 
-	brasero_burn_session_remove_flag (priv->session, BRASERO_DRIVE_PROPERTIES_FLAGS);
-	brasero_burn_session_add_flag (priv->session, flags);
+	/* check each flag before re-adding it */
+	brasero_dest_selection_add_drive_properties_flags (self,
+							   flags,
+							   &supported,
+							   &compulsory);
 
 	/* NOTE: we save even if result != BRASERO_BURN_OK. That way if a flag
 	 * is no longer supported after the removal of a plugin then the 
@@ -1158,25 +1139,6 @@ brasero_dest_selection_check_drive_settings (BraseroDestSelection *self,
 	/* save potential changes for the new profile */
 	brasero_dest_selection_save_drive_properties (self);
 
-	if (supported & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE) {
-		/* clean up the disc and have more space when possible */
-		brasero_burn_session_add_flag (priv->session,
-					       BRASERO_BURN_FLAG_FAST_BLANK|
-					       BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE);
-	}
-	else
-		brasero_burn_session_remove_flag (priv->session,
-						  BRASERO_BURN_FLAG_FAST_BLANK|
-						  BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE);
-
-	/* use DAO whenever it's possible */
-	if (supported & BRASERO_BURN_FLAG_DAO)
-		brasero_burn_session_add_flag (priv->session,
-					       BRASERO_BURN_FLAG_DAO);
-	else
-		brasero_burn_session_remove_flag (priv->session,
-						  BRASERO_BURN_FLAG_DAO);
-
 	if (priv->drive_prop) {
 		/* the dialog may need to be updated */
 		brasero_drive_properties_set_flags (BRASERO_DRIVE_PROPERTIES (priv->drive_prop),
@@ -1184,14 +1146,40 @@ brasero_dest_selection_check_drive_settings (BraseroDestSelection *self,
 						    supported,
 						    compulsory);
 	}
+
+	/* Once we've updated the flags, send a signal to tell whether we
+	 * support this disc or not. Update everything. */
+	result = brasero_burn_caps_is_session_supported (priv->caps, priv->session);
+	g_signal_emit (self,
+		       brasero_dest_selection_signals [VALID_MEDIA_SIGNAL],
+		       0,
+		       (result == BRASERO_BURN_OK));
+	if (priv->button)
+		gtk_widget_set_sensitive (priv->button, (result == BRASERO_BURN_OK));
+
+	gtk_widget_set_sensitive (priv->copies_box, (result == BRASERO_BURN_OK));
 }
 
 static void
-brasero_dest_selection_check_after_change (BraseroDestSelection *self)
+brasero_dest_selection_source_changed (BraseroBurnSession *session,
+				       BraseroDestSelection *self)
+{
+	/* NOTE: that can't happen if we are going to write to an image since
+	 * that would mean we are changing the image format (something we don't
+	 * do. So it has to be when we write to a drive */
+	brasero_dest_selection_set_drive_properties (self);
+}
+
+static void
+brasero_dest_selection_caps_changed (BraseroPluginManager *manager,
+				     BraseroDestSelection *self)
 {
 	NautilusBurnDrive *drive;
 	BraseroDestSelectionPrivate *priv;
 
+	/* In this case we are still in the same context (same src, dest) so we
+	 * check that all current flags and such are still valid */
+
 	priv = BRASERO_DEST_SELECTION_PRIVATE (self);
 
 	/* The caps of the library / the source have changed so we must check:
@@ -1209,21 +1197,6 @@ brasero_dest_selection_check_after_change (BraseroDestSelection *self)
 	nautilus_burn_drive_unref (drive);
 }
 
-static void
-brasero_dest_selection_source_changed (BraseroBurnSession *session,
-				       BraseroDestSelection *self)
-{
-	brasero_dest_selection_set_drive_properties (self);
-	brasero_dest_selection_check_after_change (self);
-}
-
-static void
-brasero_dest_selection_caps_changed (BraseroBurnCaps *caps,
-				     BraseroDestSelection *self)
-{
-	brasero_dest_selection_check_after_change (self);
-}
-
 static void
 brasero_dest_selection_output_changed (BraseroBurnSession *session,
 				       BraseroDestSelection *self)
@@ -1254,16 +1227,13 @@ brasero_dest_selection_output_changed (BraseroBurnSession *session,
 		gint numcopies;
 
 		brasero_dest_selection_set_drive_properties (self);
-		brasero_dest_selection_check_drive_settings (self, burner);
 
-		gtk_widget_set_sensitive (priv->copies_box, TRUE);
 		gtk_widget_show (priv->copies_box);
 
 		numcopies = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (priv->copies_spin));
 		brasero_burn_session_set_num_copies (priv->session, numcopies);
 	}
 	else {
-		gtk_widget_set_sensitive (priv->copies_box, FALSE);
 		gtk_widget_hide (priv->copies_box);
 		brasero_burn_session_set_num_copies (priv->session, 1);
 
@@ -1283,6 +1253,10 @@ brasero_dest_selection_drive_changed (BraseroDriveSelection *selection,
 	BraseroDestSelectionPrivate *priv;
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (selection);
+
+	if (!priv->session)
+		return;
+
 	brasero_burn_session_set_burner (priv->session, drive);
 
 	if (brasero_burn_session_same_src_dest_drive (priv->session))
@@ -1305,12 +1279,14 @@ static void
 brasero_dest_selection_init (BraseroDestSelection *object)
 {
 	BraseroDestSelectionPrivate *priv;
+	BraseroPluginManager *manager;
 	GtkWidget *label;
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (object);
 
 	priv->caps = brasero_burn_caps_get_default ();
-	priv->caps_sig = g_signal_connect (G_OBJECT (priv->caps),
+	manager = brasero_plugin_manager_get_default ();
+	priv->caps_sig = g_signal_connect (manager,
 					   "caps-changed",
 					   G_CALLBACK (brasero_dest_selection_caps_changed),
 					   object);
@@ -1345,6 +1321,8 @@ brasero_dest_selection_init (BraseroDestSelection *object)
 			  G_CALLBACK (brasero_dest_selection_copies_num_changed_cb),
 			  object);
 
+	brasero_drive_selection_set_show_all_drives (BRASERO_DRIVE_SELECTION (object), FALSE);
+
 	priv->default_ext = TRUE;
 	priv->default_path = TRUE;
 	priv->default_format = TRUE;
@@ -1368,7 +1346,10 @@ brasero_dest_selection_finalize (GObject *object)
 	}
 
 	if (priv->caps_sig) {
-		g_signal_handler_disconnect (priv->caps, priv->caps_sig);
+		BraseroPluginManager *manager;
+
+		manager = brasero_plugin_manager_get_default ();
+		g_signal_handler_disconnect (manager, priv->caps_sig);
 		priv->caps_sig = 0;
 	}
 
